api.alarms.v1.test_helpers.alarm package — Argus-Toolbelt 1.0 documentation

# api.alarms.v1.test_helpers.alarm package

## Submodules

## api.alarms.v1.test_helpers.alarm.add_alarm module

`api.alarms.v1.test_helpers.alarm.add_alarm.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.add_alarm.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.add_alarm.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.add_alarm.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.add_alarm_comment module

`api.alarms.v1.test_helpers.alarm.add_alarm_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.add_alarm_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.add_alarm_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.add_alarm_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.delete_alarm module

`api.alarms.v1.test_helpers.alarm.delete_alarm.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.delete_alarm.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.delete_alarm.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.delete_alarm.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.delete_alarm_comment module

`api.alarms.v1.test_helpers.alarm.delete_alarm_comment.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment/w+, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.delete_alarm_comment.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment/w+, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.delete_alarm_comment.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment/w+, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.delete_alarm_comment.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/comment/w+, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.get_alarm_by_id module

`api.alarms.v1.test_helpers.alarm.get_alarm_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.get_alarm_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.get_alarm_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.get_alarm_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.get_alarms module

`api.alarms.v1.test_helpers.alarm.get_alarms.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.get_alarms.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.get_alarms.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.get_alarms.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.map_to_alarm module

`api.alarms.v1.test_helpers.alarm.map_to_alarm.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/map, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.map_to_alarm.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/map, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.map_to_alarm.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/map, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.map_to_alarm.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/map, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.search_alarms module

`api.alarms.v1.test_helpers.alarm.search_alarms.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/search, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.search_alarms.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/search, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.search_alarms.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/search, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.search_alarms.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/search, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.unmap module

`api.alarms.v1.test_helpers.alarm.unmap.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/unmap, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.unmap.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/unmap, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.unmap.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/unmap, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.unmap.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+/unmap, respond with HTTP 401

## api.alarms.v1.test_helpers.alarm.update_alarm module

`api.alarms.v1.test_helpers.alarm.update_alarm.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 403

`api.alarms.v1.test_helpers.alarm.update_alarm.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 404

`api.alarms.v1.test_helpers.alarm.update_alarm.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 200

`api.alarms.v1.test_helpers.alarm.update_alarm.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/alarms/v1/alarm/w+, respond with HTTP 401

## Module contents